from django.contrib import admin
from reversion.admin import VersionAdmin

from greg.models import (
    Person,
    PersonRole,
    Role,
    PersonIdentity,
    Consent,
    PersonConsent,
    OrganizationalUnit,
    Sponsor,
    SponsorOrganizationalUnit,
)

admin.site.site_header = "Guest Registration Admin"


class RoleInline(admin.TabularInline):
    model = PersonRole
    extra = 1


class PersonIdentityInline(admin.TabularInline):
    model = PersonIdentity
    extra = 1


class ConsentInline(admin.TabularInline):
    model = PersonConsent
    extra = 1


class PersonAdmin(VersionAdmin):
    list_display = (
        "first_name",
        "last_name",
        "role_count",
    )
    search_fields = ("first_name", "last_name")  # TODO: "identities__value"?
    readonly_fields = ("id", "created", "updated")
    inlines = (RoleInline, PersonIdentityInline, ConsentInline)

    def role_count(self, person):
        return str(person.roles.count())

    role_count.short_description = "# roles"  # type: ignore


class PersonRoleAdmin(VersionAdmin):
    list_display = ("id", "person", "role")
    search_fields = (
        "person__id",
        "role__id",
    )
    raw_id_fields = ("person", "role")
    readonly_fields = ("id", "created", "updated")


class RoleAdmin(VersionAdmin):
    list_display = ("id", "type", "name_nb", "name_en")
    readonly_fields = ("id", "created", "updated")


class PersonIdentityAdmin(VersionAdmin):
    list_display = ("id", "person", "type", "verified")
    list_filter = ("verified",)
    readonly_fields = ("id", "created", "updated")


class ConsentAdmin(admin.ModelAdmin):
    list_display = ("id", "consent_name_en", "valid_from", "user_allowed_to_change")
    readonly_fields = ("id", "created", "updated")


class PersonConsentAdmin(VersionAdmin):
    list_display = ("id", "person", "get_consent_name_en")
    readonly_fields = ("id", "created", "updated")

    def get_consent_name_en(self, obj):
        return obj.consent.consent_name_en

    get_consent_name_en.short_description = "Consent name"  # type: ignore


class OrganizationalUnitAdmin(VersionAdmin):
    list_display = ("id", "name_en", "parent")
    readonly_fields = ("id", "created", "updated")


class OrganizationalUnitInline(admin.TabularInline):
    model = SponsorOrganizationalUnit
    extra = 1


class SponsorAdmin(VersionAdmin):
    list_display = ("id", "feide_id")
    inlines = (OrganizationalUnitInline,)
    readonly_fields = ("id", "created", "updated")


class SponsorOrganizationalUnitAdmin(VersionAdmin):
    readonly_fields = ("id", "created", "updated")


admin.site.register(Person, PersonAdmin)
admin.site.register(PersonRole, PersonRoleAdmin)
admin.site.register(Role, RoleAdmin)
admin.site.register(PersonIdentity, PersonIdentityAdmin)
admin.site.register(Consent, ConsentAdmin)
admin.site.register(PersonConsent, PersonConsentAdmin)
admin.site.register(OrganizationalUnit, OrganizationalUnitAdmin)
admin.site.register(Sponsor, SponsorAdmin)
admin.site.register(SponsorOrganizationalUnit, SponsorOrganizationalUnitAdmin)
