from rest_framework import serializers

from greg.models import Person, PersonRole, Role, PersonIdentity


class PersonSerializer(serializers.ModelSerializer):
    class Meta:
        model = Person
        fields = [
            "id",
            "first_name",
            "last_name",
            "date_of_birth",
            "email",
            "mobile_phone",
            "email_verified_date",
            "mobile_phone",
            "mobile_phone_verified_date",
            "registration_completed_date",
            "token",
        ]


class PersonRoleSerializer(serializers.ModelSerializer):
    role = serializers.SlugRelatedField(queryset=Role.objects.all(), slug_field="type")

    class Meta:
        model = PersonRole
        fields = [
            "id",
            "start_date",
            "end_date",
            "registered_by",
            "unit",
            "created",
            "updated",
            "role",
        ]


class PersonIdentitySerializer(serializers.ModelSerializer):
    class Meta:
        model = PersonIdentity
        fields = "__all__"

    def is_duplicate(self, identity_type: str, value: str) -> bool:
        # Guests may be verified using another unrecognised identification method,
        # which the sponsor is required to elaborate in the value column.
        # In this case we cannot assume the union of the identity type and
        # the value to be unique across all records.
        if identity_type == PersonIdentity.IdentityType.OTHER:
            return False

        # If the type is a specific ID type, then duplicates are not expected
        return (
            PersonIdentity.objects.filter(type__like=identity_type)
            .filter(value__like=value)
            .exists()
        )
