from django.urls import (
    re_path,
)
from rest_framework.routers import DefaultRouter

from greg.api.views.consent import ConsentViewSet
from greg.api.views.organizational_unit import OrganizationalUnitViewSet
from greg.api.views.person import (
    PersonRoleViewSet,
    PersonViewSet,
    PersonIdentityViewSet,
)
from greg.api.views.role import RoleViewSet
from greg.api.views.sponsor import SponsorViewSet, SponsorGuestsViewSet

router = DefaultRouter()
router.register(r"persons", PersonViewSet, basename="person")
router.register(r"roles", RoleViewSet, basename="role")
router.register(r"consents", ConsentViewSet, basename="consent")
router.register(r"sponsors", SponsorViewSet, basename="sponsor")
router.register(r"orgunit", OrganizationalUnitViewSet, basename="orgunit")


urlpatterns = router.urls

urlpatterns += [
    re_path(
        r"^persons/(?P<person_id>[0-9]+)/roles/$",
        PersonRoleViewSet.as_view({"get": "list", "post": "create"}),
        name="person_role-list",
    ),
    re_path(
        r"^persons/(?P<person_id>[0-9]+)/roles/(?P<id>[0-9]+)/$",
        PersonRoleViewSet.as_view(
            {"get": "retrieve", "patch": "partial_update", "delete": "destroy"}
        ),
        name="person_role-detail",
    ),
    re_path(
        r"^persons/(?P<person_id>[0-9]+)/identities/$",
        PersonIdentityViewSet.as_view({"get": "list", "post": "create"}),
        name="person_identity-list",
    ),
    re_path(
        r"^persons/(?P<person_id>[0-9]+)/identities/(?P<id>[0-9]+)$",
        PersonIdentityViewSet.as_view(
            {"get": "retrieve", "delete": "destroy", "patch": "partial_update"}
        ),
        name="person_identity-detail",
    ),
    re_path(
        r"^sponsors/(?P<sponsor_id>[0-9]+)/guests/$",
        SponsorGuestsViewSet.as_view({"get": "list"}),
        name="sponsor_guests-list",
    ),
]
